
from typing import Any

class PyJwtEncoderDecoder:
    def __init__(self, private_key: bytes, public_key: bytes, leeway: int) -> None: ...
    
    def encode_claims_json_str(self, claims_str: str) -> str: ...
    
    def encode_claims_json_obj(self, claims: Any) -> str: ...
    
    def decode(self, token: str) -> Any: ...

